summaryrefslogtreecommitdiff
path: root/framework/core.php
diff options
context:
space:
mode:
authorxue <>2006-01-21 20:26:20 +0000
committerxue <>2006-01-21 20:26:20 +0000
commitb4d398680ea7dfee8ce5db5956efd373c541a585 (patch)
tree0f44da4989400152d3f1755ef1f6ec6763c6c8f7 /framework/core.php
parent88d880aa189f23e3c1e5664016e927cbc94bd0e9 (diff)
Enhanced template parsing so the error messages can be reported with the file and line information.
Diffstat (limited to 'framework/core.php')
-rw-r--r--framework/core.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/core.php b/framework/core.php
index 97b5c9dc..f3d826cc 100644
--- a/framework/core.php
+++ b/framework/core.php
@@ -528,7 +528,7 @@ class PradoBase
* Uses a namespace.
* A namespace ending with an asterisk '*' refers to a directory, otherwise it represents a PHP file.
* If the namespace corresponds to a directory, the directory will be appended
* to the include path. If the namespace corresponds to a file, it will be included (require_once).
* @param string namespace to be used
* @throws TInvalidDataValueException if the namespace is invalid
*/
@@ -538,7 +538,7 @@ class PradoBase
return;
if(($pos=strrpos($namespace,'.'))===false) // a class name
{
- require_once($namespace.self::CLASS_FILE_EXT);
+ include_once($namespace.self::CLASS_FILE_EXT);
if(!class_exists($namespace,false))
throw new TInvalidOperationException('prado_component_unknown',$namespace);
}
@@ -561,7 +561,7 @@ class PradoBase
{
self::$_usings[$namespace]=$path;
if(!class_exists($className,false))
- require_once($path);
+ include_once($path);
}
else
throw new TInvalidDataValueException('prado_using_invalid',$namespace);
@@ -528,7 +528,7 @@ class PradoBase
* A namespace ending with an asterisk '*' refers to a directory, otherwise it represents a PHP file.
* If the namespace corresponds to a directory, the directory will be appended
- * to the include path. If the namespace corresponds to a file, it will be included (require_once).
+ * to the include path. If the namespace corresponds to a file, it will be included (include_once).
* @param string namespace to be used
* @throws TInvalidDataValueException if the namespace is invalid